% SPDX-FileCopyrightText: 2023 Info3 https://www.informatik.uni-wuerzburg.de/comnet/
% SPDX-FileCopyrightText: 2023-2024 Philip Bergmann <philip.bergmann@uni-wuerzburg.de>
% SPDX-License-Identifier: LPPL-1.3c

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{scrsthesis}[2024/02/27 SCRS Thesis Class]
% The date format should be YYYY/MM/DD :(

%-------------------------------------------------------------------------------
%   Options, Parameters and Superclass
%-------------------------------------------------------------------------------

% Options defining the superclass
\newcommand{\scrsthesis@scls}{scrskoma}

% Writeup type, the different localisations
\newcommand{\scrsthesis@type@de}{Arbeitstyp via type=bachelor|master|...}
\newcommand{\scrsthesis@type@en}{Set type with type=bachelor|master|...}

\DeclareOption{type=bachelor}{
    \renewcommand{\scrsthesis@type@de}{Bachelorarbeit}
    \renewcommand{\scrsthesis@type@en}{Bachelor's Thesis}
}

\DeclareOption{type=master}{
    \renewcommand{\scrsthesis@type@de}{Masterarbeit}
    \renewcommand{\scrsthesis@type@en}{Master's Thesis}
}

% All unknown parameters get passed to the superclass
% I am not sure why this is needed b/c the documentclass options
% are global options and therefore should also be seen by the superclass.
% But it is required
\DeclareOption*{
    \PassOptionsToClass{\CurrentOption}{\scrsthesis@scls}
}

% Process options in the order they appear
% (w/o star options are processed in the order declared in the package file)
% https://tex.stackexchange.com/a/82441
\ProcessOptions*

% Default options for superclasses could be specified here with
\PassOptionsToClass{scls=scrreprt}{\scrsthesis@scls}

% load superclass
\LoadClass{\scrsthesis@scls}

%-------------------------------------------------------------------------------
%   Packages
%-------------------------------------------------------------------------------

% For \IfStrEq
\RequirePackage{xstring}


%-------------------------------------------------------------------------------
%   Thesis specific things
%-------------------------------------------------------------------------------

% Used on the title page, provides the textblock env
% the abolsut and overlay modes are seemingly package options
\RequirePackage[absolute,overlay]{textpos}

\newcommand{\@matrikelnumber}{}
\newcommand{\matrikelnummer}[1]{\renewcommand\@matrikelnumber{#1}}

\newcommand{\scrsthesis@supervisors}{}
\newcommand{\supervisors}[1]{\renewcommand\scrsthesis@supervisors{#1}}

\newcommand{\@duedate}{\today}
\newcommand{\duedate}[1]{\renewcommand\@duedate{#1}}

\definecolor{titleblue}{RGB}{6,61,121}
\definecolor{titlewhite}{RGB}{255,255,255}

% Localized labels for the title page
\newcommand{\scrsthesis@type}{
    \IfStrEq{de}{\localeinfo{language.tag.bcp47}}{\scrsthesis@type@de}{\scrsthesis@type@en}
}

\newcommand{\scrsthesis@chairlabel}{%
    \IfStrEq{de}{\localeinfo{language.tag.bcp47}}{%
        Institut für Informatik\\
        Satellite Communication and Radar Systems%
    }{%
        Institute of Computer Science\\
        Satellite Communication and Radar Systems%
    }%
}

\newcommand{\scrsthesis@supervisorlabel}{%
    \IfStrEq{de}{\localeinfo{language.tag.bcp47}}{Betreuer}{Supervisors}
}

\newcommand{\scrsthesis@submissionlabel}{%
    \IfStrEq{de}{\localeinfo{language.tag.bcp47}}{Abgabe der Arbeit}{Submission}
}

\renewcommand\maketitle{
\begin{titlepage}

\begin{tikzpicture}[remember picture,overlay]
    % ^ `remember picture, overlay` is required to reference the `current page` node
    % see pfgmanual, 17.13.2 Referencing the Current Page Node – Absolute Positioning

    % `current page.north west` is the top left corner of the page
    % place a box thats shifted 57mm to the right with a minimum width and height of 20 and 30 cm there
    % (so larger than the reamining space on the page) to color the whole right side of the paper blue.
    % The 57mm shift is taken from the info3 template.
    \node [anchor=north west, xshift=57mm, minimum width=20cm, minimum height=30cm, fill=titleblue] (bluebox) at (current page.north west) {};

    % place the uni logo relative to the resulting position of the bluebox (that is, top of the page, some mms to the right)
    % shifted by 25mm left (this is exactly the width of the blue sideways 'U' thingy), and
    % shifted by 65mm down
    \node [anchor=north west, xshift=-25mm, yshift=-65mm, inner sep=0pt] (unilogo) at (bluebox.north west) {\includegraphics{logos/unilogo_mit_siegelbalken_Vektor_CMYK.eps}};

    % Now place the chair logo vertically centered on the unilogo, 155mm to the right of its beginning
    % (the latter number has been found by trial and error) 
    \node [anchor=west, xshift=155mm, inner sep=0pt] (chairlogo) at (unilogo.west) {\includegraphics[width=2cm]{logos/scrs_logo.pdf}};

    \node [anchor=east, xshift=150mm, inner sep=0pt] (chairtext) at (unilogo.west) {%
        \textsf{%
            \fontsize{12pt}{14pt}\selectfont%
            \shortstack[r]{\scrsthesis@chairlabel}%
        }%
    };
\end{tikzpicture}


\begin{textblock*}{115mm}(70mm,45mm)
    \noindent\Large\textsf{\textcolor{titlewhite}{%
        \scrsthesis@type%
    }}%
\end{textblock*}

\begin{textblock*}{115mm}(70mm,105mm)
    \noindent\raggedright\LARGE\textsf{\textbf{\textcolor{titlewhite}{%
        \@title%
    }}}%
\end{textblock*}

\begin{textblock*}{115mm}(70mm,205mm)
    \noindent\large\textsf{\textcolor{titlewhite}{%
        \textbf{\@author}\\%
        \@matrikelnumber%
    }}%
\end{textblock*}

\begin{textblock*}{115mm}(70mm,230mm)
    \noindent\large\textsf{\textcolor{titlewhite}{%
        \textbf{\scrsthesis@supervisors}\\%
        \scrsthesis@supervisorlabel%
    }}%
\end{textblock*}


\begin{textblock*}{60mm}(70mm,270mm)
    \noindent\large\textsf{\textcolor{titlewhite}{%
        \textbf{\scrsthesis@submissionlabel}\\%
        \@duedate%
    }}%
\end{textblock*}

\end{titlepage}
}
